@@ -14,7 +14,10 @@ import sys
 import optparse
 import os.path
 
-import amimodel as ami
+from numpy import array
+
+#import amimodel as ami           # Use this one for development/testing.
+import pyibisami.amimodel as ami # Use this one for distribution.
 
 _plot_name_base = 'plot'
 _plot_name_ext = 'png'
@@ -93,7 +96,7 @@ def main():
                     if(not toks or toks[0].startswith('#')):
                         continue
                     expr += line
-                    if(line.endswith('\\\n')):
+                    if(toks[-1] == '\\'): # Test for line continuation.
                         expr = expr.rstrip('\\\n')
                     else:
                         param_list.append(eval(expr))
